import re
import pyrpm.spec

def re_tag_compile(tag):
    return re.compile(tag, re.IGNORECASE)

ENTRY_HEXSHA = "#Hexsha:"

tagsHack = [
    pyrpm.spec._NameValue("name", re_tag_compile(r"^Name:\s*(\S+)")),
    pyrpm.spec._NameValue("sha", re_tag_compile(r"^{}\s*(\S+)".format(ENTRY_HEXSHA))),
    pyrpm.spec._NameValue("version", re_tag_compile(r"^Version:\s*(\S+)")),
    pyrpm.spec._NameValue("epoch", re_tag_compile(r"^Epoch:\s*(\S+)")),
    pyrpm.spec._NameValue("release", re_tag_compile(r"^Release:\s*(\S+)")),
    pyrpm.spec._NameValue("summary", re_tag_compile(r"^Summary:\s*(.+)")),
    pyrpm.spec._NameValue("license", re_tag_compile(r"^License:\s*(.+)")),
    pyrpm.spec._NameValue("group", re_tag_compile(r"^Group:\s*(\S+)")),
    pyrpm.spec._NameValue("url", re_tag_compile(r"^URL:\s*(\S+)")),
    pyrpm.spec._NameValue("buildroot", re_tag_compile(r"^BuildRoot:\s*(\S+)")),
    pyrpm.spec._NameValue("buildarch", re_tag_compile(r"^BuildArch:\s*(\S+)")),
    pyrpm.spec._NameValue("excludearch", re_tag_compile(r"^ExcludeArch:\s*(\S+)")),
    pyrpm.spec._ListAndDict(
        "sources",
        re_tag_compile(r"^(Source\d*):\s*(\S+)")),
    pyrpm.spec._ListAndDict(
        "patches",
        re_tag_compile(r"^(Patch\d*):\s*(\S+)")),
    pyrpm.spec._List(
        "build_requires",
        re_tag_compile(r"^BuildRequires:\s*(.+)")),
    pyrpm.spec._List("requires", re_tag_compile(r"^Requires:\s*(.+)")),
    pyrpm.spec._List("conflicts", re_tag_compile(r"^Conflicts:\s*(.+)")),
    pyrpm.spec._List("obsoletes", re_tag_compile(r"^Obsoletes:\s*(.+)")),
    pyrpm.spec._List("provides", re_tag_compile(r"^Provides:\s*(.+)")),
    pyrpm.spec._List('packages', re.compile(r'^%package\s+(\S+)')),
    pyrpm.spec._MacroDef('define', re.compile(r'^%define\s+(\S+)\s+(\S+)')),
    pyrpm.spec._MacroDef('global', re.compile(r'^%global\s+(\S+)\s+(\S+)'))
]

pyrpm.spec._tags = tagsHack
Spec = pyrpm.spec.Spec